Crate discreet_common

Crate discreet_common 

Re-exports

pub use diff_eq::Derivative;
pub use diff_eq::Variable;

Modules

diff_eq

Structs

Dirichlet
A marker struct that indicates a Dirichlet boundary condition
Neumann
A marker struct that indicates a Dirichlet boundary condition
Node2D
A node in a 2-dimensional finite difference method. This corresponds to the term u[i+I, j+J].

Traits

FiniteDifferenceStencil2D
A struct implementing this trait can be used as the stencil for a finite difference method. This trait is not intended to be manually implemented but rather to be implemented through the stencil macro.