Crate discreet_common
discreet_
common
0.1.0
All Items
Crate Items
Re-exports
Modules
Structs
Traits
Crate
discreet_
common
Re-exports

pub use diff_eq::
Derivative
;
pub use diff_eq::
Variable
;
Modules

diff_eq
Structs

Dirichlet
A marker struct that indicates a Dirichlet boundary condition
Neumann
A marker struct that indicates a Dirichlet boundary condition
Node2D
A node in a 2-dimensional finite difference method. This corresponds to the term u[i+I, j+J].
Traits

Finite
Difference
Stencil2D
A struct implementing this trait can be used as the stencil for a finite difference method. This trait is not intended to be manually implemented but rather to be implemented through the
stencil
macro.